PyXMake Developer Guide: PyXMake.VTL.ssh_ifort Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.ssh_ifort Namespace Reference

## Functions
def | main (BuildID, user, key, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(5), source=os.path.join(__mcd_core_path,"src"), include=[posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")], make=__mcd_cluster_dev, link=[posixpath.join(__mcd_cluster_libpath,"libinterpx64.a"), posixpath, join, __mcd_cluster_libpath, libpchipx64, a, posixpath, join, __mcd_cluster_libpath, libbbeamx64, a, posixpath, join, __mcd_cluster_libpath, libmueslix64, a, posixpath, join, __mcd_cluster_libpath, libdispmodulex64, a, posixpath, join, __mcd_cluster_libpath, libtomsx64, a, environment=VTL.GetEnvironment(0), architecture="x64", scratch=VTL.Scratch, verbosity=0, incremental=False, host="129.247.54.37", port=22, kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the institute cluster")
| metavar
| nargs
| help
| args
| user = args.user[0]
| key = args.key[0]
| box_source = os.path.join(__mcd_core_path,"external","boxbeam")
list | box_make = [posixpath.join(__mcd_cluster_dev,"include","boxbeam"), posixpath.join(__mcd_cluster_dev,"lib")]
| files
| source = os.path.join(__mcd_core_path,"external",BuildID)
| include
| make = [posixpath.join(__mcd_cluster_dev,"include","toms"),posixpath.join(__mcd_cluster_dev,"lib")]
| link
| disp_source = os.path.join(__mcd_core_path,"external","dispmodule","Fortran90","Src")
list | disp_make = [posixpath.join(__mcd_cluster_dev,"include","dispmodule"), posixpath.join(__mcd_cluster_dev,"lib")]
| command
| incremental
list | BuildIDs = [os.path.splitext(x)[0].lower() for x in VTL.GetSourceCode(6)]
list | srcfile = [x for x in VTL.GetSourceCode(6) if x.startswith(BuildID)]
string | style = False
| toms_source = os.path.join(__mcd_core_path,"external","toms")
| BuildID
| combine
| libs
dictionary | pchip_replace
| precommand
| replace

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile Fortran source on the institute cluster.
                 Uses main function

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake
          - SSH key

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.ssh_ifort.main | ( |  | BuildID,
|  |  | user,
|  |  | key,
|  |  | files = `VTL.GetSourceCode(0)`,
|  |  | command = `VTL.GetBuildCommand(5)`,
|  |  | source = `os.path.join(__mcd_core_path,"src")`,
|  |  | include = `[posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")]`,
|  |  | make = `__mcd_cluster_dev`,
|  |  | link = `[posixpath.join(__mcd_cluster_libpath,"libinterpx64.a")`,
|  |  | posixpath,
|  |  | join,
|  |  | __mcd_cluster_libpath,
|  |  | libpchipx64,
|  |  | a,
|  |  | posixpath,
|  |  | join,
|  |  | __mcd_cluster_libpath,
|  |  | libbbeamx64,
|  |  | a,
|  |  | posixpath,
|  |  | join,
|  |  | __mcd_cluster_libpath,
|  |  | libmueslix64,
|  |  | a,
|  |  | posixpath,
|  |  | join,
|  |  | __mcd_cluster_libpath,
|  |  | libdispmodulex64,
|  |  | a,
|  |  | posixpath,
|  |  | join,
|  |  | __mcd_cluster_libpath,
|  |  | libtomsx64,
|  |  | a,
|  |  | environment = `VTL.GetEnvironment(0)`,
|  |  | architecture = `"x64"`,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `0`,
|  |  | incremental = `False`,
|  |  | host = `"129.247.54.37"`,
|  |  | port = `22`,
|  |  | kwargs
| ) |  |

    Main function to execute the script.

Definition at line 79 of file ssh_ifort.py.

## Variable Documentation

## ◆ pchip_replace

dictionary PyXMake.VTL.ssh_ifort.pchip_replace

Initial value:
1 = {'FUNCTION RAND ( R )':'FUNCTION RAND ( R ) BIND(C, NAME="pchip_rand")',
2 'subroutine timestamp ( )':'subroutine timestamp ( ) BIND(C, NAME="pchip_timestamp")'}

Definition at line 165 of file ssh_ifort.py.